<?php

namespace App\Jobs;

use App\Library\Traits\Trackable;
use App\Models\Campaigns;
use Exception;
use Illuminate\Bus\Batchable;

class LoadCampaign extends Base
{
    use Trackable, Batchable;

    protected Campaigns $campaign;
    public int          $timeout = 7200;


    /**
     * Create a new job instance.
     */
    public function __construct(Campaigns $campaign)
    {
        $this->campaign = $campaign;
    }

    /**
     * Execute the job.
     *
     * @throws Exception
     */
    public function handle(): void
    {
        if ($this->batch()->cancelled()) {
            return;
        }

        $this->campaign->processing();

        $loadLimit = 100 + rand(1, 9);

        $this->campaign->prepare(function ($campaign, $contact, $server, $priceOption) {
            $job         = new SendMessage($campaign, $contact, $server, $priceOption);
            $stopOnError = $this->campaign->stopOnError();
            $job->setStopOnError($stopOnError);

            $this->batch()->add($job);
        }, $loadLimit);
    }
}
